@@ -17,12 +17,13 @@ class provider_failTest extends \PHPUnit\Framework\TestCase
      * @param mixed $v1
      * @param mixed $v2
      */
+    #[\PHPUnit\Framework\Attributes\DataProvider('provider')]
     public function testProvider($v1, $v2)
     {
         $this->assertEquals($v1, $v2);
     }
 
-    public function provider()
+    public static function provider(): array
     {
         return [
             [true, true],
